@@ -7,7 +7,14 @@ import logging
 import numpy as np
 import pandas as pd
 from sklearn.impute import SimpleImputer
-from sklearn.preprocessing import StandardScaler, MinMaxScaler, OneHotEncoder, FunctionTransformer
+from sklearn.preprocessing import (
+    StandardScaler,
+    MinMaxScaler,
+    OneHotEncoder,
+    OrdinalEncoder,
+    LabelEncoder,
+    FunctionTransformer
+)
 from sklearn.compose import ColumnTransformer
 
 from skippa.transformers import ColumnSelector, SkippaMixin
@@ -48,27 +55,34 @@ def make_skippa_column_transformer(
     )
 
 
-class SkippaSimpleImputer(SimpleImputer, SkippaMixin):
+class SkippaSimpleImputer(SkippaMixin, SimpleImputer):
     """Wrapper round sklearn's SimpleImputer"""
 
     def __init__(self, cols: ColumnSelector, **kwargs) -> None:
         self._set_columns(cols)
+        if kwargs.get('strategy', 'mean') == 'most_frequent':
+            self._dtype_required = 'string'
+            kwargs['missing_values'] = None
+        else:
+            self._dtype_required = 'numeric'
+            kwargs['missing_values'] = np.nan
+
         super().__init__(**kwargs)
 
     def fit(self, X, y=None, **kwargs):
-        column_names = self._evaluate_columns(X)
+        column_names = self._evaluate_columns(X, check_dtypes=self._dtype_required)
         super().fit(X[column_names], **kwargs)
         return self
 
     def transform(self, X, y=None, **kwargs):
-        column_names = self._evaluate_columns(X)
+        column_names = self._evaluate_columns(X, check_dtypes=self._dtype_required)
         res = super().transform(X[column_names], **kwargs)
         df = X.copy()
         df.loc[:, column_names] = res
         return df
 
 
-class SkippaStandardScaler(StandardScaler, SkippaMixin):
+class SkippaStandardScaler(SkippaMixin, StandardScaler):
     """Wrapper round sklearn's StandardScaler"""
 
     def __init__(self, cols: ColumnSelector, **kwargs) -> None:
@@ -76,19 +90,19 @@ class SkippaStandardScaler(StandardScaler, SkippaMixin):
         super().__init__(**kwargs)
 
     def fit(self, X, y=None, **kwargs):
-        column_names = self._evaluate_columns(X)
+        column_names = self._evaluate_columns(X, check_dtypes='numeric')
         super().fit(X[column_names], **kwargs)
         return self
 
     def transform(self, X, y=None, **kwargs):
-        column_names = self._evaluate_columns(X)
+        column_names = self._evaluate_columns(X, check_dtypes='numeric')
         res = super().transform(X[column_names], **kwargs)
         df = X.copy()
         df.loc[:, column_names] = res
         return df
 
 
-class SkippaMinMaxScaler(MinMaxScaler, SkippaMixin):
+class SkippaMinMaxScaler(SkippaMixin, MinMaxScaler):
     """Wrapper round sklearn's MinMaxScaler"""
 
     def __init__(self, cols: ColumnSelector, **kwargs) -> None:
@@ -96,23 +110,24 @@ class SkippaMinMaxScaler(MinMaxScaler, SkippaMixin):
         super().__init__(**kwargs)
 
     def fit(self, X, y=None, **kwargs):
-        column_names = self._evaluate_columns(X)
+        column_names = self._evaluate_columns(X, check_dtypes='numeric')
         super().fit(X[column_names], **kwargs)
         return self
 
     def transform(self, X, y=None, **kwargs):
-        column_names = self._evaluate_columns(X)
+        column_names = self._evaluate_columns(X, check_dtypes='numeric')
         res = super().transform(X[column_names], **kwargs)
         df = X.copy()
         df.loc[:, column_names] = res
         return df
 
 
-class SkippaOneHotEncoder(OneHotEncoder, SkippaMixin):
+class SkippaOneHotEncoder(SkippaMixin, OneHotEncoder):
     """Wrapper round sklearn's OneHotEncoder"""
 
     def __init__(self, cols: ColumnSelector, **kwargs) -> None:
         self._set_columns(cols)
+        kwargs['sparse'] = False  # never output a sparse matrix
         super().__init__(**kwargs)
 
     def fit(self, X, y=None, **kwargs):
@@ -125,5 +140,46 @@ class SkippaOneHotEncoder(OneHotEncoder, SkippaMixin):
         data_new = super().transform(X[column_names], **kwargs)
         df_new = X.drop(column_names, axis=1)
         new_column_names = self.get_feature_names_out()
+        assert len(new_column_names) == data_new.shape[1], "Nr. of expected vs. actual columns doesn't match"
         df_new.loc[:, new_column_names] = data_new
         return df_new
+
+
+class SkippaOrdinalEncoder(SkippaMixin, OrdinalEncoder):
+    """Wrapper round sklearn's OrdinalEncoder"""
+
+    def __init__(self, cols: ColumnSelector, **kwargs) -> None:
+        self._set_columns(cols)
+        super().__init__(**kwargs)
+
+    def fit(self, X, y=None, **kwargs):
+        column_names = self._evaluate_columns(X)
+        super().fit(X[column_names], **kwargs)
+        return self
+
+    def transform(self, X, y=None, **kwargs):
+        column_names = self._evaluate_columns(X)
+        encoded = super().transform(X[column_names], **kwargs)
+        df = X.copy()
+        df.loc[:, column_names] = encoded
+        return df
+
+
+class SkippaLabelEncoder(SkippaMixin, LabelEncoder):
+    """Wrapper round sklearn's LabelEncoder"""
+
+    def __init__(self, cols: ColumnSelector, **kwargs) -> None:
+        self._set_columns(cols)
+        super().__init__(**kwargs)
+
+    def fit(self, X, y=None, **kwargs):
+        column_names = self._evaluate_columns(X)
+        super().fit(X[column_names], **kwargs)
+        return self
+
+    def transform(self, X, y=None, **kwargs):
+        column_names = self._evaluate_columns(X)
+        encoded = super().transform(X[column_names], **kwargs)
+        df = X.copy()
+        df.loc[:, column_names] = encoded
+        return df
